
div.phpdebugbar-widgets-mails span.phpdebugbar-widgets-subject {
  display: block;
}

div.phpdebugbar-widgets-mails li.phpdebugbar-widgets-list-item pre.phpdebugbar-widgets-headers {
  display: none;
  margin: 10px;
  padding: 5px;
  border: 1px solid #ddd;
  font-family: "SFMono-Regular", Consolas, "Liberation Mono", Menlo, Courier, monospace;
}
